summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorAlexandru Scvortov <alexandru@rabbitmq.com>2011-07-27 15:20:03 +0100
committerAlexandru Scvortov <alexandru@rabbitmq.com>2011-07-27 15:20:03 +0100
commite32bf003b8a6a0bc9f65536b0b111d72f536d439 (patch)
tree12aaa7b92bf02ea36d824d94551ac2424d3ae027
parent7e5da1ef7376fbbf9bb5547d103e6d25e69348f5 (diff)
downloadrabbitmq-server-e32bf003b8a6a0bc9f65536b0b111d72f536d439.tar.gz
remove some magic
-rw-r--r--src/rabbit_mnesia.erl9
1 files changed, 3 insertions, 6 deletions
diff --git a/src/rabbit_mnesia.erl b/src/rabbit_mnesia.erl
index 16bdc7f9..1081f0cb 100644
--- a/src/rabbit_mnesia.erl
+++ b/src/rabbit_mnesia.erl
@@ -194,10 +194,9 @@ nodes_of_type(Type) ->
%% This function should return the nodes of a certain type (ram,
%% disc or disc_only) in the current cluster. The type of nodes
%% is determined when the cluster is initially configured.
- %% Specifically, we check whether a certain table, which we know
- %% will be written to disk on a disc node, is stored on disk or in
- %% RAM.
- mnesia:table_info(rabbit_durable_exchange, Type).
+ %% Specifically, we check whether the schema, which we know will
+ %% be written to disk on a disc node, is stored on disk or in RAM.
+ mnesia:table_info(schema, Type).
%% The tables aren't supposed to be on disk on a ram node
table_definitions(disc) ->
@@ -260,8 +259,6 @@ table_definitions() ->
{type, ordered_set},
{match, #topic_trie_binding{trie_binding = trie_binding_match(),
_='_'}}]},
- %% Consider the implications to nodes_of_type/1 before altering
- %% the next entry.
{rabbit_durable_exchange,
[{record_name, exchange},
{attributes, record_info(fields, exchange)},